@@ -58,7 +58,7 @@ class Viewer3D(object):
 
             - cut1DFunctionRectangle (function): Function to be called when performing an interactive rectangle (default None)
 
-            - cut1DFunctionCircle (function): Function to be called when performing an interactive rectangle (default None)
+            - cut1DFunctionCircle (function): Function to be called when performing an interactive circle (default None)
 
         For an example, see the `quick plotting tutorial <../Tutorials/Quick/QuickView3D.html>`_ under scripting tutorials.
 
@@ -73,7 +73,7 @@ class Viewer3D(object):
 
 
         self.currentData = None
-        
+        self.ds = dataset
 
         self.plotCurratAxe = plotCurratAxe # Set to false but will change to True when correct list is created
         self._CurratAxeBraggList = None
@@ -114,6 +114,8 @@ class Viewer3D(object):
         if ax is None: # TODO: REDO with actual correct axes!
             self.figure = plt.figure()
             self.ax = plt.subplot(gs[0])#self.figure.add_subplot(111)
+            self.ax.isActive = lambda : True
+            self.ax.drawState = States.INACTIVE
             self.xlabel = r'Qx [$A^{-1}$]'
             self.ylabel = r'Qy [$A^{-1}$]'
             self.zlabel = r'E [meV]'
@@ -269,7 +271,11 @@ class Viewer3D(object):
             self.axQxE.isActive = False
             self.axQyE.isActive = False
 
+            if not cut1DFunctionRectangle is None:
+                self.axRLU.cut1DFunctionRectangle = lambda dr: cut1DFunctionRectangle(viewer=self,dr=dr)
 
+            if not cut1DFunctionCircle is None:
+                self.axRLU.cut1DFunctionCircle = lambda dr: cut1DFunctionCircle(viewer=self,dr=dr)
         else:
             self.ax._button_press_event = self.figure.canvas.mpl_connect('key_press_event',lambda event: onkeypress(event, self) )
             self.onClick = lambda event: eventdecorator(onclick,self,self.ax,event,outputFunction=outputFunction)
@@ -574,6 +580,61 @@ class Viewer3D(object):
     def set_title(self,title):
         self.ax.set_title(title)
 
+    def saveToFile(self,folder,extension,gui=None):
+        """Save all planes to files
+        
+        Args:
+
+            - folder (path): Folder in which to save files
+
+            - extension (str): name of wanted extension. Must be accepted by matplotlib
+
+        Kwargs:
+
+            - gui (PyQt5 MainApplication): Used for MJOLNIR Gui
+        """
+        XLength,YLength,ZLength = self.Data.shape
+
+        startProjection = self.axis
+        startPosition = self.Energy_slider.val
+
+        totalFigures = XLength+YLength+ZLength
+        if not gui is None:
+            gui.setProgressBarMaximum(totalFigures)
+            progress = 0
+            gui.setProgressBarValue(progress) 
+        self.setProjection(2)
+        for zidx in range(ZLength):
+            self.setPlane(zidx)
+            Energy = self.bins[2][0,0,zidx]
+            self.figure.savefig(os.path.join(folder,'E{}.{}'.format('{:.2f}'.format(Energy).replace('.','p').replace('-','m'),extension)))
+            if not gui is None:
+                progress += 1
+                gui.setProgressBarValue(progress)
+
+        self.setProjection(0)
+
+        for xidx in range(XLength):
+            self.setPlane(xidx)
+            position = self.bins[0][xidx,0,0]
+            self.figure.savefig(os.path.join(folder,'X{}.{}'.format('{:.2f}'.format(position).replace('.','p').replace('-','m'),extension)))
+            if not gui is None:
+                progress += 1
+                gui.setProgressBarValue(progress)
+            
+        self.setProjection(1)
+
+        for yidx in range(YLength):
+            self.setPlane(yidx)
+            position = self.bins[1][0,yidx,0]
+            self.figure.savefig(os.path.join(folder,'Y{}.{}'.format('{:.2f}'.format(position).replace('.','p').replace('-','m'),extension)))
+            if not gui is None:
+                progress += 1
+                gui.setProgressBarValue(progress)
+            
+        self.setProjection(startProjection)
+        self.setPlane(startPosition)
+
 
 def eventdecorator(function,self,ax,event,*args,**kwargs):# pragma: no cover
     if event.xdata is not None and ax.in_axes(event) and ax.isActive:
